pub struct MDBFileInfo {
pub metadata: FileDataSequenceHeader,
pub segments: Vec<FileDataSequenceEntry>,
pub verification: Vec<FileVerificationEntry>,
pub metadata_ext: Option<FileMetadataExt>,
}Fields
metadata: FileDataSequenceHeadersegments: Vec<FileDataSequenceEntry>verification: Vec<FileVerificationEntry>metadata_ext: Option<FileMetadataExt>Implementations
Sourceimpl MDBFileInfo
impl MDBFileInfo
pub fn num_bytes(&self) -> u64
pub fn serialize<W: Write>(&self, writer: &mut W) -> Result<usize, Error>
pub fn deserialize<R: Read>(reader: &mut R) -> Result<Option<Self>, Error>
pub fn contains_verification(&self) -> bool
pub fn contains_metadata_ext(&self) -> bool
Sourcepub fn merge_from(&mut self, other: &Self) -> Result<()>
pub fn merge_from(&mut self, other: &Self) -> Result<()>
Merges the content of other into the content of self if needed. After this call, self will have the verification info and metadata extension if they exist in the other object but not this one.