#[repr(u8)]pub enum CompressionScheme {
None = 0,
LZ4 = 1,
ByteGrouping4LZ4 = 2,
Auto = 99,
}Expand description
Dis-allow the value of ascii capital letters as valid CompressionScheme, 65-90
Variants
Implementations
Sourceimpl CompressionScheme
impl CompressionScheme
Sourcepub fn resolve_for_data(&self, data: &[u8]) -> Self
pub fn resolve_for_data(&self, data: &[u8]) -> Self
Resolves Auto to a concrete scheme by analyzing the data.
pub fn compress_from_slice<'a>(&self, data: &'a [u8]) -> Result<Cow<'a, [u8]>>
pub fn decompress_from_slice<'a>(&self, data: &'a [u8]) -> Result<Cow<'a, [u8]>>
pub fn decompress_from_reader<R: Read, W: Write>( &self, reader: &mut R, writer: &mut W, ) -> Result<u64>
Sourcepub fn choose_from_data(data: &[u8]) -> Self
pub fn choose_from_data(data: &[u8]) -> Self
Chooses the compression scheme based on a KL-divergence heuristic.