pub struct SerializedXorbObject {
pub serialized_data: Vec<u8>,
pub hash: MerkleHash,
pub raw_num_bytes: u64,
pub num_chunks: usize,
pub footer_start: Option<u64>,
}Expand description
A convenience struct that holds the raw information for the upload path.
Fields
serialized_data: Vec<u8>The serialized data and header; can be uploaded as a blob.
hash: MerkleHashThe xorb hash
raw_num_bytes: u64Number of bytes before compression; to be used for progress reporting.
num_chunks: usizeFor logging
Implementations
Sourceimpl SerializedXorbObject
impl SerializedXorbObject
Sourcepub fn from_xorb(
xorb: RawXorbData,
serialize_footer: bool,
) -> Result<Self, CoreError>
pub fn from_xorb( xorb: RawXorbData, serialize_footer: bool, ) -> Result<Self, CoreError>
Builds the xorb from raw xorb data.
The compression scheme is determined by HF_XET_XORB_COMPRESSION_POLICY:
auto-detect (default) or an explicit scheme (none, lz4, bg4-lz4).
Sourcepub fn from_xorb_with_compression(
xorb: RawXorbData,
compression_scheme: CompressionScheme,
serialize_footer: bool,
) -> Result<Self, CoreError>
pub fn from_xorb_with_compression( xorb: RawXorbData, compression_scheme: CompressionScheme, serialize_footer: bool, ) -> Result<Self, CoreError>
Builds the xorb from raw xorb data with an explicit compression scheme override.