XorbObjectInfoV0

Struct XorbObjectInfoV0 

pub struct XorbObjectInfoV0 {
    pub ident: XorbObjectIdent,
    pub version: u8,
    pub xorb_hash: MerkleHash,
    pub num_chunks: u32,
    pub chunk_boundary_offsets: Vec<u32>,
    pub chunk_hashes: Vec<MerkleHash>,
    /* private fields */
}
Info struct for XorbObject. This is stored at the end of the XORB. DO NOT USE in any new code

Fields

ident: XorbObjectIdent

XORB identifier: “XETBLOB”

version: u8

Format version, expected to be 0 right now.

xorb_hash: MerkleHash

256-bits, 32-bytes, The XORB Hash of this Xorb.

num_chunks: u32

Total number of chunks in the Xorb. Length of chunk_boundary_offsets & chunk_hashes vectors.

chunk_boundary_offsets: Vec<u32>

Byte offset marking the boundary of each chunk. Length of vector is num_chunks.

This vector only contains boundaries, so assumes the first chunk starts at offset 0. The final entry in vector is the total length of the chunks. See example below. chunk[n] are bytes in [chunk_boundary_offsets[n-1], chunk_boundary_offsets[n])

// ex.             chunks: [  0,   1,   2,   3 ]
// chunk_boundary_offsets: [ 100, 200, 300, 400]
chunk_hashes: Vec<MerkleHash>

Merklehash for each chunk stored in the Xorb. Length of vector is num_chunks.

Implementations

Source

impl XorbObjectInfoV0

pub fn serialize<W: Write>(&self, writer: &mut W) -> Result<usize, CoreError>

👎Deprecated

Serialize XorbObjectInfoV0 to provided Writer.

Assumes caller has set position of Writer to appropriate location for serialization.

pub fn deserialize<R: Read>(reader: &mut R) -> Result<(Self, u32), CoreError>

👎Deprecated

Construct XorbObjectInfoV0 object from Read.

Expects metadata struct is found at end of Reader, written out in struct order.

pub fn deserialize_v0<R: Read>(reader: &mut R) -> Result<(Self, u32), CoreError>

pub async fn deserialize_async<R: AsyncRead + Unpin>( reader: &mut R, version: u8, ) -> Result<(Self, u32), CoreError>

Construct XorbObjectInfo object from AsyncRead. assumes that the ident and version have already been read and verified.

verifies that the length of the footer data matches the length field at the very end of the buffer