#[repr(C)]pub struct FileDataSequenceHeader {
pub file_hash: MerkleHash,
pub file_flags: u32,
pub num_entries: u32,
pub _unused: u64,
}Expand description
Each file consists of a FileDataSequenceHeader following a sequence of FileDataSequenceEntry, maybe a sequence of FileVerificationEntry, and maybe a FileMetadataExt determined by file flags.
Fields
file_hash: MerkleHashfile_flags: u32num_entries: u32_unused: u64Implementations
Sourceimpl FileDataSequenceHeader
impl FileDataSequenceHeader
pub fn new<I: TryInto<u32>>( file_hash: MerkleHash, num_entries: I, contains_verification: bool, contains_metadata_ext: bool, ) -> Self
pub fn bookend() -> Self
pub fn is_bookend(&self) -> bool
pub fn serialize<W: Write>(&self, writer: &mut W) -> Result<usize, Error>
pub fn deserialize<R: Read>(reader: &mut R) -> Result<Self, Error>
pub fn contains_metadata_ext(&self) -> bool
pub fn contains_verification(&self) -> bool
Sourcepub fn num_info_entry_following(&self) -> u32
pub fn num_info_entry_following(&self) -> u32
Get the number of info entries following the header in this shard, this includes “FileDataSequenceEntry“s, “FileVerificationEntry“s, and “FileMetadataExt”.
Sourcepub fn verify_same_file(header1: &Self, header2: &Self)
pub fn verify_same_file(header1: &Self, header2: &Self)
Verifies that the two headers correspond to the same file. Checks that the file hashes are the same and that the number of entries are the same.
Sourcepub fn compare_flag_superset(header_a: &Self, header_b: &Self) -> SupersetResult
pub fn compare_flag_superset(header_a: &Self, header_b: &Self) -> SupersetResult
Compares the flags of headers A and B to determine if either bitmap is a superset of the other. Can return 4 possible responses:
- SuperA if A is a superset of B (e.g. A has validation and B has nothing)
- SuperB if B is a superset of A (e.g. B has metadata_ext and A has nothing)
- Neither if neither A nor B are supersets of each other (e.g. A has only validation, and B has only metadata_ext)
- Equal if both A and B have the same flags set.